package net.sourceforge.nrl.parser.model;

import java.util.List;

/**
 * Utility methods for working with model objects.
 * @author Matthew Smith
 *
 */

public class ModelUtils {

	/**
	 * Finds an attribute within the given {@link IClassifier} whose originalName matches 
	 * that specified.
	 * @param container The IClassifier to search for attributes.
	 * @param originalName The name of the attribute as specified in the original e.g. XSD
	 * @param includeInherited 
	 * @return
	 */
	public static IAttribute getAttributeByOriginalName(IClassifier container, String originalName, boolean includeInherited){
		if(originalName == null){
			throw new IllegalArgumentException("originalName cannot be null");
		}
		if(container == null){
			throw new IllegalArgumentException("container cannot be null");
		}
		List<IAttribute> attributes = container.getAttributes(includeInherited);
		for (IAttribute attribute : attributes) {
			if(originalName.equals(attribute.getOriginalName())){
				return attribute;
			}
		}
		return null;
	}
	
}
